localization2D_nws {#master}
-------------------------

### Devices

#### `localization2D_nws_yarp`

* This new device implements a new yarp-only wrapper for devices which implement the `ILocalization2D` interface.
* The implementation is inspired by the original wrapper `localization2DServer`.

#### `localization2D_nws_ros`

* This new device implements a new ros-only wrapper for devices which implement the `ILocalization2D` interface.
* The implementation is inspired by the original wrapper `localization2DServer`.